@@ -6,32 +6,24 @@ from cacholote import config
 
 
 def test_change_engine(tmpdir: pathlib.Path) -> None:
-    old_db = config.SETTINGS.get().cache_db_urlpath
+    old_db = config.get().cache_db_urlpath
     new_db = "sqlite:///" + str(tmpdir / "dummy.db")
     old_engine = config.ENGINE.get()
 
     with config.set(cache_db_urlpath=new_db):
         assert config.ENGINE.get() is not old_engine
-        assert (
-            str(config.ENGINE.get().url)
-            == config.SETTINGS.get().cache_db_urlpath
-            == new_db
-        )
+        assert str(config.ENGINE.get().url) == config.get().cache_db_urlpath == new_db
     assert config.ENGINE.get() is old_engine
-    assert (
-        str(config.ENGINE.get().url) == config.SETTINGS.get().cache_db_urlpath == old_db
-    )
+    assert str(config.ENGINE.get().url) == config.get().cache_db_urlpath == old_db
 
     config.set(cache_db_urlpath=new_db)
     assert config.ENGINE.get() is not old_engine
-    assert (
-        str(config.ENGINE.get().url) == config.SETTINGS.get().cache_db_urlpath == new_db
-    )
+    assert str(config.ENGINE.get().url) == config.get().cache_db_urlpath == new_db
 
 
 def test_expiration() -> None:
     with config.set(expiration="1492-10-12T00:00:00"):
-        assert config.SETTINGS.get().expiration == "1492-10-12T00:00:00"
+        assert config.get().expiration == "1492-10-12T00:00:00"
 
 
 def test_env_variables(tmpdir: pathlib.Path) -> None:
@@ -46,9 +38,9 @@ def test_env_variables(tmpdir: pathlib.Path) -> None:
 
     config.reset(str(dotenv_path))
     try:
-        assert config.SETTINGS.get().cache_db_urlpath == "sqlite://"
+        assert config.get().cache_db_urlpath == "sqlite://"
         assert str(config.ENGINE.get().url) == "sqlite://"
-        assert config.SETTINGS.get().io_delete_original is True
+        assert config.get().io_delete_original is True
         assert str(config.ENGINE.get().url) == "sqlite://"
     finally:
         os.environ.clear()
@@ -62,5 +54,5 @@ def test_contextvar() -> None:
     ctx = contextvars.copy_context()
     ctx.run(set_tag)
 
-    assert config.SETTINGS.get().tag is None
+    assert config.get().tag is None
     assert ctx[config.SETTINGS].tag == "foo"
